% ultrasonic - analyse and plot data from ultrasonic reflection measurements
% Copyright 2023 Jakob Harden (jakob.harden@tugraz.at, Graz University of Technology, Graz, Austria)
% License: MIT
% This program was written in the course of the lecture 'Anwendung ZfP- und Monitoringverfahren [206.554]'
% 
% Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
% documentation files (the “Software”), to deal in the Software without restriction, including without 
% limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of 
% the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
% 
% THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO 
% THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
% AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, 
% TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
%
## Plot data structure (signals and wavelet analysis results)
##
## Usage: [r_fh] = us_plot(p_ds, p_tp)
##
## p_ds ... grid data, structure
## p_tp ... plot type, integer, default = 1
##           1: plot x=sample-number y=magnitude
##           2: plot x=sample-time, y=magnitude
##           3: plot x=sample-distance, y=magnitude
## r_fh ... return: figure handles, figure_handle array
##
## Note: see us_createstruct for details on structure fields
##
function [r_fh] = us_plot_project(p_ds, p_tp)
  
  figure();
  title(sprintf('Grid data - %s', strrep(p_ds.pn, '_', '-')));
  xlabel('Samples [ ]');
  ylabel('Voltage [mV]');
  hold on;
  
  for i = 1 : size(p_ds.arr_ds, 1)
    for j = 1 : size(p_ds.arr_ds, 2)
      yy = p_ds.arr_ds(i, j).yy;
      if not(isempty(yy))
        plbl = sprintf(';GP %d-%d;', j, i);
        plot(yy, plbl);
      endif
    endfor
  endfor
  
  legend("location", "northeast");
  hold off;
  
endfunction
